0.3 (2018-02-06)
================

- added `file.mv()`

- clever handling of Ctrl-C

0.2 (2017-09-24)
================

- remote py26 support

- use assyncssh (you can still use ssh binary with the --ssh switch)

- delay ssh connection with the -d switch. .2s by default

- gpg support for files and templates put()


0.1 (2017-02-03)
================

- Initial release
